@@ -49,14 +49,14 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 	tabLayout1->setSpacing( 6 );
 	tabLayout1->setMargin( 15 );
 	pixmapLabel1 = new QLabel( tab, "PixmapLabel1" );
-	pixmapLabel1->setPixmap(loadIcon("scribus_logo.jpg"));
+	pixmapLabel1->setPixmap(loadIcon("scribus_logo.png"));
 	pixmapLabel1->setAlignment(Qt::AlignCenter);
 	tabLayout1->addWidget( pixmapLabel1 );
 	buildID = new QLabel( tab, "BB" );
 	buildID->setAlignment(Qt::AlignCenter);
-	QString BUILD_DAY = "04";
-	QString BUILD_MONTH = CommonStrings::december;
-	QString BUILD_YEAR = "2006";
+	QString BUILD_DAY = "09";
+	QString BUILD_MONTH = CommonStrings::january;
+	QString BUILD_YEAR = "2007";
 	QString BUILD_TIME = "";
 	QString BUILD_TZ = "";
 	QString BUILD_NAME = "";
@@ -169,12 +169,17 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Jean-Jacques Sarton</td><td>jj.sarton@t-online.de</td></tr>" +
 											"<tr><td>Christian Töpp</td><td>mr-ct@gmx.de</td></tr>" +
 											"<tr><td>Eirik Øverby</td><td>ltning@anduin.net</td></tr>" +
+											"<tr><td>Kevin Young</td><td>k.young@youngscomputing.com</td></tr>" +
 											"<tr><td></td><td></td></tr>" +
 
 											"<tr><td><b>" + tr("Mac OS&#174; X Aqua Port:").utf8()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Andreas Vox</td><td>avox@arcor.de</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 
+											"<tr><td><b>" + tr("OS/2&#174;/eComStation&#8482; Port:").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td>Paul Smedley</td><td>paul@smedley.info</td></tr>" +
+											"<tr><td> </td><td> </td></tr>" +
+
 											"<tr><td><b>" + tr("Windows&#174; Port:").utf8()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Jean Ghali</td><td>jghali@libertysurf.fr</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
@@ -225,6 +230,8 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Morten Langlo</td><td>mlanglo@mail.dk</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("nl").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td>Foppe Benedictus</td><td>foppe.benedictus@gmail.coml</td></tr>" +
+											"<tr><td>Erik Collou</td><td>collou@gmx.net</td></tr>" +
 											"<tr><td>Wilbert Berendsen</td><td>wbsoft@xs4all.nl</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("en_AU").utf8()  + "</b></td><td></td></tr>" +
@@ -273,6 +280,7 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Kitae Kim</td><td>neeum@yahoo.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("nb").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td>Axel Bojer</td><td>axelb@skolelinux.no</td></tr>" +
 											"<tr><td>Klaus Ade Johnstad</td><td>klaus@inout.no</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("pl").utf8()  + "</b></td><td> </td></tr>" +
@@ -342,7 +350,6 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Aivaras Kirejevas</td><td>kiras@mail.lt</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("nb").utf8()  + "</b></td><td></td></tr>" +
-											"<tr><td>Axel Bojer</td><td>axelb@skolelinux.no</td></tr>" +
 											"<tr><td>Johannes Wilm</td><td>j@indymedia.no</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("tr").utf8()  + "</b></td><td> </td></tr>" +
