@@ -9,7 +9,9 @@ for which a new license (GPL+exception) is in place.
 
 #include <qdom.h>
 #include <qptrstack.h>
+#include <qsize.h>
 #include "pluginapi.h"
+#include "fpointarray.h"
 #include "loadsaveplugin.h"
 #include "../formatidlist.h"
 #include "vgradient.h"
@@ -186,7 +188,19 @@ public:
 	void convert(int flags);
 	void addGraphicContext();
 	void setupTransform( const QDomElement &e );
+	bool isIgnorableNode( const QDomElement &e );
+	QSize parseWidthHeight(const QDomElement &e, double conv);
+	QRect parseViewBox(const QDomElement &e);
+	void parseDefs(const QDomElement &e);
+	void parseClipPath(const QDomElement &e);
+	void parseClipPathAttr(const QDomElement &e, FPointArray& clipPath);
 	QPtrList<PageItem> parseGroup(const QDomElement &e);
+	QPtrList<PageItem> parseElement(const QDomElement &e);
+	QPtrList<PageItem> parseText(const QDomElement &e);
+	QPtrList<PageItem> parseTextElement(double x, double y, const QDomElement &e);
+	QPtrList<PageItem> parseSwitch(const QDomElement &e);
+	QPtrList<PageItem> parseUse(const QDomElement &e);
+	QDomElement getNodeFromUseElement(const QDomElement &e);
 	double fromPercentage( const QString &s );
 	double parseUnit(const QString &unit);
 	QWMatrix parseTransform(const QString &transform);
@@ -205,16 +219,15 @@ public:
 	void parseGradient( const QDomElement &e );
 	FPoint GetMaxClipO(FPointArray Clip);
 	FPoint GetMinClipO(FPointArray Clip);
-	QPtrList<PageItem> parseText(const QDomElement &e);
-	QPtrList<PageItem> parseTextElement(double x, double y, const QDomElement &e);
 
 	ScribusDoc* currDoc;
 	QDomDocument inpdoc;
 	double CurrX, CurrY, StartX, StartY, Conversion;
 	int PathLen;
-	QPtrList<PageItem> Elements;
 	QPtrStack<SvgStyle>	m_gc;
 	QMap<QString, GradientHelper>	m_gradients;
+	QMap<QString, QDomElement>		m_nodeMap;
+	QMap<QString, FPointArray>		m_clipPaths;
 	bool FirstM, WasM, PathClosed;
 	double viewTransformX;
 	double viewTransformY;
